pub struct Counterexample {
pub prng: Prng,
pub limit: Limit,
pub hints: Option<Hints>,
pub error: Error,
}Expand description
Contains details about a failed test run.
Fields
prng: PrngThe initial state of the number generator the counterexample has used for generating test data.
limit: LimitThe limit for dynamic data structures the counterexample has used for generating test data.
hints: Option<Hints>The hints collected during the counterexample run.
If hints are enabled, the runner tries to rerun the counterexample to collect hints. Rerunning the counterexample can fail if the test is not deterministic.
error: ErrorThe error occurred during the counterexample run.